summaryrefslogtreecommitdiff
path: root/devel/unproven-pthreads/patches/patch-an
diff options
context:
space:
mode:
Diffstat (limited to 'devel/unproven-pthreads/patches/patch-an')
-rw-r--r--devel/unproven-pthreads/patches/patch-an52
1 files changed, 24 insertions, 28 deletions
diff --git a/devel/unproven-pthreads/patches/patch-an b/devel/unproven-pthreads/patches/patch-an
index 81686a650f1..8c9c9f3c524 100644
--- a/devel/unproven-pthreads/patches/patch-an
+++ b/devel/unproven-pthreads/patches/patch-an
@@ -1,15 +1,11 @@
-$NetBSD: patch-an,v 1.2 2001/01/10 03:18:17 briggs Exp $
+$NetBSD: patch-an,v 1.3 2002/03/25 16:08:31 briggs Exp $
--- /dev/null Wed Dec 31 19:00:00 1969
+++ machdep/syscall-powerpc-netbsd.S Tue Jan 9 10:42:07 2001
-@@ -0,0 +1,185 @@
+@@ -0,0 +1,181 @@
+#include <machine/asm.h>
+#define COMPAT_43
+#include <sys/syscall.h>
-+#ifndef __CONCAT
-+#include <sys/cdefs.h>
-+#endif
-+#define CONCAT __CONCAT
+
+#undef SYSCALL
+
@@ -31,20 +27,20 @@ $NetBSD: patch-an,v 1.2 2001/01/10 03:18:17 briggs Exp $
+ SYSCALL invocation. */
+
+ENTRY(machdep_cerror)
-+ mflr 0 # Save LR in 0
-+ stwu 1,-16(1) # allocate new stack frame
-+ stw 0,20(1) # Stash 0 in stack
-+ stw 31,8(1) # Stash 31 in stack (since it's callee-saved
-+ mr 31,3 # and we stash return there)
++ mflr 0 /* Save LR in 0 */
++ stwu 1,-16(1) /* allocate new stack frame */
++ stw 0,20(1) /* Stash 0 in stack */
++ stw 31,8(1) /* Stash 31 in stack (since it's callee-saved */
++ mr 31,3 /* and we stash return there) */
+ bl PIC_PLT(_C_LABEL(__errno))
-+ stw 31,0(3) # *errno() = err
-+ lwz 0,20(1) # Restore LR from stack to 0
-+ neg 3,31 # return -errno to 3
-+ lwz 31,8(1) # Restore 31 from stack
++ stw 31,0(3) /* *errno() = err */
++ lwz 0,20(1) /* Restore LR from stack to 0 */
++ neg 3,31 /* return -errno to 3 */
++ lwz 31,8(1) /* Restore 31 from stack */
+ mtlr 0
-+ la 1,16(1) # Restore stack frame
-+ li 4,-1 # Put -1 in r4 for those syscalls that return
-+ blr # two values
++ la 1,16(1) /* Restore stack frame */
++ li 4,-1 /* Put -1 in r4 for those syscalls that ret */
++ blr /* two values */
+
+/* The fork system call is special... */
+ENTRY(machdep_sys_fork)
@@ -60,10 +56,10 @@ $NetBSD: patch-an,v 1.2 2001/01/10 03:18:17 briggs Exp $
+ li 0,SYS_pipe
+ sc
+ bso PIC_PLT(_C_LABEL(machdep_cerror))
-+ stw 3,0(5) # Success, store fds
++ stw 3,0(5) /* Success, store fds */
+ stw 4,4(5)
+ li 3,0
-+ blr # And return 0
++ blr /* And return 0 */
+
+#ifndef SYS___sigsuspend14
+/* The sigsuspend system call is special... */
@@ -77,20 +73,20 @@ $NetBSD: patch-an,v 1.2 2001/01/10 03:18:17 briggs Exp $
+#ifndef SYS___sigprocmask14
+/* The sigprocmask system call is special... */
+ENTRY(machdep_sys_sigprocmask)
-+ or. 4,4,4 # Set == NULL ?
-+ li 6,1 # how = SIG_BLOCK
++ or. 4,4,4 /* Set == NULL ? */
++ li 6,1 /* how = SIG_BLOCK */
+ beq Ldoit
-+ lwz 4,0(4) # if not, replace it in r4 with #set
++ lwz 4,0(4) /* if not, replace it in r4 with #set */
+ mr 6,3
-+Ldoit: mr 3,6 # ... using sigprocmask(SIG_BLOCK)
++Ldoit: mr 3,6 /* ... using sigprocmask(SIG_BLOCK) */
+ li 0,SYS_compat_13_sigprocmask13
+ sc
+ bso PIC_PLT(_C_LABEL(machdep_cerror))
-+ or. 5,5,5 # Check to see if oset requested
-+ beq Ldone # if oset != NULL
-+ stw 3,0(5) # *oset = oldmask
++ or. 5,5,5 /* Check to see if oset requested */
++ beq Ldone /* if oset != NULL */
++ stw 3,0(5) /* *oset = oldmask */
+Ldone:
-+ li 3,0 # return 0
++ li 3,0 /* return 0 */
+ blr
+#endif /* SYS_sigprocmask14 */
+